pub struct ProtocolAddress { /* private fields */ }Expand description
Represents a unique Signal client instance as (<user ID>, <device ID>) pair.
Implementations
Sourceimpl ProtocolAddress
impl ProtocolAddress
Sourcepub fn new(name: String, device_id: DeviceId) -> ProtocolAddress
pub fn new(name: String, device_id: DeviceId) -> ProtocolAddress
Create a new address.
namedefines a user’s public identity, and therefore must be globally unique to that user.- Each Signal client instance then has its own
device_id, which must be unique among all clients for that user.
use libsignal_core::{DeviceId, ProtocolAddress};
// This is a unique id for some user, typically a UUID.
let user_id: String = "04899A85-4C9E-44CC-8428-A02AB69335F1".to_string();
// Each client instance representing that user has a unique device id.
let device_id: DeviceId = 2_u32.try_into().unwrap();
let address = ProtocolAddress::new(user_id.clone(), device_id);
assert!(address.name() == &user_id);
assert!(address.device_id() == device_id);Sourcepub fn device_id(&self) -> DeviceId
pub fn device_id(&self) -> DeviceId
An identifier representing a particular Signal client instance to send to.
For example, if a user has set up Signal on both their phone and laptop, a particular message sent to the user will still only go to a single device. So when a user sends a message to another user at all, they’re actually sending a message to every device.